REST WebService for GuessIt
===========================

.. image:: http://img.shields.io/pypi/v/guessit-rest.svg
    :target: https://pypi.python.org/pypi/guessit-rest
    :alt: Latest Version

.. image:: http://img.shields.io/badge/license-LGPLv3-blue.svg
    :target: https://pypi.python.org/pypi/guessit-rest
    :alt: LGPLv3 License

.. image:: http://img.shields.io/travis/Toilal/guessit-rest.svg
    :target: https://travis-ci.org/Toilal/guessit-rest
    :alt: Build Status

.. image:: http://img.shields.io/coveralls/Toilal/guessit-rest.svg
    :target: https://coveralls.io/github/Toilal/guessit-rest
    :alt: Coveralls

GuessIt is a python library that extracts as much information as possible from a video filename.

This is the REST WebService for `GuessIt <https://github.com/wackou/guessit>`_.

License
-------

GuessIt is licensed under the `LGPLv3 license <http://www.gnu.org/licenses/lgpl.html>`_.
